"""LCM type definitions
This file automatically generated by lcm.
DO NOT MODIFY BY HAND!!!!
"""

try:
    import cStringIO.StringIO as BytesIO
except ImportError:
    from io import BytesIO
import struct

import compas_lcmtypes.stdlcm.header_t

class battery_t(object):
    __slots__ = ["header", "voltage", "temperature", "current", "charge"]

    __typenames__ = ["compas_lcmtypes.stdlcm.header_t", "double", "double", "double", "double"]

    __dimensions__ = [None, None, None, None, None]

    def __init__(self):
        self.header = compas_lcmtypes.stdlcm.header_t()
        self.voltage = 0.0
        self.temperature = 0.0
        self.current = 0.0
        self.charge = 0.0

    def encode(self):
        buf = BytesIO()
        buf.write(battery_t._get_packed_fingerprint())
        self._encode_one(buf)
        return buf.getvalue()

    def _encode_one(self, buf):
        assert self.header._get_packed_fingerprint() == compas_lcmtypes.stdlcm.header_t._get_packed_fingerprint()
        self.header._encode_one(buf)
        buf.write(struct.pack(">dddd", self.voltage, self.temperature, self.current, self.charge))

    def decode(data):
        if hasattr(data, 'read'):
            buf = data
        else:
            buf = BytesIO(data)
        if buf.read(8) != battery_t._get_packed_fingerprint():
            raise ValueError("Decode error")
        return battery_t._decode_one(buf)
    decode = staticmethod(decode)

    def _decode_one(buf):
        self = battery_t()
        self.header = compas_lcmtypes.stdlcm.header_t._decode_one(buf)
        self.voltage, self.temperature, self.current, self.charge = struct.unpack(">dddd", buf.read(32))
        return self
    _decode_one = staticmethod(_decode_one)

    def _get_hash_recursive(parents):
        if battery_t in parents: return 0
        newparents = parents + [battery_t]
        tmphash = (0x8ebb4d983630afcf+ compas_lcmtypes.stdlcm.header_t._get_hash_recursive(newparents)) & 0xffffffffffffffff
        tmphash  = (((tmphash<<1)&0xffffffffffffffff) + (tmphash>>63)) & 0xffffffffffffffff
        return tmphash
    _get_hash_recursive = staticmethod(_get_hash_recursive)
    _packed_fingerprint = None

    def _get_packed_fingerprint():
        if battery_t._packed_fingerprint is None:
            battery_t._packed_fingerprint = struct.pack(">Q", battery_t._get_hash_recursive([]))
        return battery_t._packed_fingerprint
    _get_packed_fingerprint = staticmethod(_get_packed_fingerprint)

    def get_hash(self):
        """Get the LCM hash of the struct"""
        return struct.unpack(">Q", battery_t._get_packed_fingerprint())[0]

